@@ -17,8 +17,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import sys
-
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -27,7 +25,6 @@ from os_vif.internal.ip.api import ip as ip_lib
 from os_vif import objects
 from os_vif import plugin
 
-
 from vif_plug_ovs import constants
 from vif_plug_ovs import exception
 from vif_plug_ovs import linux_net
@@ -181,11 +178,15 @@ class OvsPlugin(plugin.PluginBase):
     def supports_tc_qdisc(self, vif) -> bool:
         if self._get_vif_datapath_type(vif) != constants.OVS_DATAPATH_SYSTEM:
             return False
-        if sys.platform == constants.PLATFORM_WIN32:
-            return False
-
         return True
 
+    def _isolate_vif(self, vif_name, bridge):
+        # NOTE(vsaienko): don't break traffic if port already exists,
+        # we assume it is called when nova-compute is initialized and
+        # since port is present it should be bound already.
+        return (self.config.isolate_vif and
+                not self.ovsdb.port_exists(vif_name, bridge))
+
     def _create_vif_port(self, vif, vif_name, instance_info, **kwargs):
         mtu = self._get_mtu(vif)
         # NOTE(sean-k-mooney): As part of a partial fix to bug #1734320
@@ -200,7 +201,8 @@ class OvsPlugin(plugin.PluginBase):
         # TODO(sean-k-mooney): Extend neutron to record what ml2 driver
         # bound the interface in the vif binding details so isolation
         # can be enabled automatically in the future.
-        if self.config.isolate_vif:
+        bridge = kwargs.pop('bridge', vif.network.bridge)
+        if self._isolate_vif(vif_name, bridge):
             kwargs['tag'] = constants.DEAD_VLAN
         qos_type = self._get_qos_type(vif)
         if qos_type is not None:
@@ -215,7 +217,6 @@ class OvsPlugin(plugin.PluginBase):
             # for more details.
             if not self.ovsdb.port_exists(vif_name, vif.network.bridge):
                 kwargs['qos_type'] = qos_type
-        bridge = kwargs.pop('bridge', vif.network.bridge)
         self.ovsdb.create_ovs_vif_port(
             bridge,
             vif_name,
@@ -276,14 +277,6 @@ class OvsPlugin(plugin.PluginBase):
             linux_net.update_veth_pair(v1_name, v2_name, mtu)
             self._update_vif_port(vif, v2_name)
 
-    def _plug_vif_windows(self, vif, instance_info):
-        """Create a per-VIF OVS port."""
-
-        if not ip_lib.exists(vif.id):
-            self.ovsdb.ensure_ovs_bridge(vif.network.bridge,
-                                         self._get_vif_datapath_type(vif))
-            self._create_vif_port(vif, vif.id, instance_info)
-
     def _plug_port_bridge(self, vif, instance_info):
         """Create a per-VIF OVS bridge and patch pair."""
 
@@ -302,7 +295,9 @@ class OvsPlugin(plugin.PluginBase):
             vif, vif.vif_name, instance_info, bridge=port_bridge_name,
             set_ids=False
         )
-        tag = constants.DEAD_VLAN if self.config.isolate_vif else None
+        tag = (constants.DEAD_VLAN
+               if self._isolate_vif(int_bridge_patch, int_bridge_name)
+               else None)
         iface_id = vif.id
         mac = vif.address
         instance_id = instance_info.uuid
@@ -372,15 +367,7 @@ class OvsPlugin(plugin.PluginBase):
             raise exception.WrongPortProfile(
                 profile=vif.port_profile.__class__.__name__)
 
-        if sys.platform == constants.PLATFORM_WIN32:
-            if type(vif) not in (
-                objects.vif.VIFOpenVSwitch, objects.vif.VIFBridge
-            ):
-                raise osv_exception.PlugException(
-                    vif=vif, err="This vif type is not supported on Windows")
-
-            self._plug_vif_windows(vif, instance_info)
-        elif isinstance(vif, objects.vif.VIFOpenVSwitch):
+        if isinstance(vif, objects.vif.VIFOpenVSwitch):
             if self.config.per_port_bridge:
                 self._plug_port_bridge(vif, instance_info)
             else:
@@ -434,12 +421,6 @@ class OvsPlugin(plugin.PluginBase):
             qos_type = self.config.default_qos_type
         return qos_type
 
-    def _unplug_vif_windows(self, vif, instance_info):
-        """Remove port from OVS."""
-        self.ovsdb.delete_ovs_vif_port(vif.network.bridge, vif.id,
-                                       delete_netdev=False)
-        self._delete_bridge_if_trunk(vif)
-
     def _unplug_port_bridge(self, vif, instance_info):
         """Create a per-VIF OVS bridge and patch pair."""
         # NOTE(sean-k-mooney): the port name prefix should not be
@@ -499,14 +480,7 @@ class OvsPlugin(plugin.PluginBase):
                           objects.vif.VIFPortProfileOpenVSwitch):
             raise exception.WrongPortProfile(
                 profile=vif.port_profile.__class__.__name__)
-        if sys.platform == constants.PLATFORM_WIN32:
-            if type(vif) not in (
-                objects.vif.VIFOpenVSwitch, objects.vif.VIFBridge
-            ):
-                raise osv_exception.UnplugException(
-                    vif=vif, err="This vif type is not supported on windows.")
-            self._unplug_vif_windows(vif, instance_info)
-        elif isinstance(vif, objects.vif.VIFOpenVSwitch):
+        if isinstance(vif, objects.vif.VIFOpenVSwitch):
             if self.config.per_port_bridge:
                 self._unplug_port_bridge(vif, instance_info)
             else:
